@@ -333,6 +333,12 @@ class H2OGBMParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnoredCo
         """Automatically export generated models to this directory.""",
         H2OTypeConverters.toNullableString())
 
+    aucType = Param(
+        Params._dummy(),
+        "aucType",
+        """Set default multinomial AUC type.""",
+        H2OTypeConverters.toEnumString("hex.MultinomialAucType"))
+
     ##
     # Getters
     ##
@@ -489,6 +495,9 @@ class H2OGBMParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnoredCo
     def getExportCheckpointsDir(self):
         return self.getOrDefault(self.exportCheckpointsDir)
 
+    def getAucType(self):
+        return self.getOrDefault(self.aucType)
+
     ##
     # Setters
     ##
@@ -644,3 +653,6 @@ class H2OGBMParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnoredCo
 
     def setExportCheckpointsDir(self, value):
         return self._set(exportCheckpointsDir=value)
+
+    def setAucType(self, value):
+        return self._set(aucType=value)
