@@ -32,6 +32,7 @@ from ..model.regression import H2ORegressionModel
 from ..model.word_embedding import H2OWordEmbeddingModel
 from ..model.anomaly_detection import H2OAnomalyDetectionModel
 from ..model.coxph import H2OCoxPHModel
+from ..model.coxph import H2OCoxPHMojoModel
 from ..model.segment_models import H2OSegmentModels
 
 
@@ -335,7 +336,7 @@ class H2OEstimator(ModelBase):
         if len(x) > 0 and is_type(x[0], int):
             x = [names[i] for i in x]
         if override_default_training_frame:
-            ignored_columns = list(set(names) - set(x + [y, offset, folds, weights] + self._additional_used_columns(parms)))
+            ignored_columns = list(set(names) - set(x + [y, offset, folds, weights]))
             parms["ignored_columns"] = None if ignored_columns == [] else [quoted(col) for col in ignored_columns]
         parms["interactions"] = (None if "interactions" not in parms or parms["interactions"] is None
                                  else [quoted(col) for col in parms["interactions"]])
@@ -526,13 +527,6 @@ class H2OEstimator(ModelBase):
         """
         return True
 
-    def _additional_used_columns(self, parms):
-        """
-        Returns list of additional columns not to automatically add to ignored_columns parameter.
-        :return: Empty list as default. Can be overridden by any specific algorithm.
-        """
-        return []
-
     @staticmethod
     def _metrics_class(model_json):
         model_type = model_json["output"]["model_category"]
@@ -567,7 +561,7 @@ class H2OEstimator(ModelBase):
             model_class = H2OAnomalyDetectionModel
         elif model_type == "CoxPH":
             metrics_class = H2OModelMetricsRegressionCoxPH
-            model_class = H2OCoxPHModel
+            model_class = H2OCoxPHModel if model_json["algo"] != "generic" else H2OCoxPHMojoModel
         elif model_type == "TargetEncoder":
             metrics_class = H2OTargetEncoderMetrics
             model_class = h2o.estimators.H2OTargetEncoderEstimator
