@@ -10,6 +10,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 from h2o.model.confusion_matrix import ConfusionMatrix
 from h2o.utils.metaclass import BackwardsCompatible, Deprecated as deprecated, h2o_meta
 from h2o.utils.compatibility import *  # NOQA
+from h2o.utils.ext_dependencies import get_matplotlib_pyplot
 from h2o.utils.typechecks import assert_is_type, assert_satisfies, is_type, numeric
 
 
@@ -101,6 +102,7 @@ class MetricsBase(h2o_meta()):
         types_w_logloss = types_w_bin + types_w_mult+types_w_ord
         types_w_dim = ["ModelMetricsGLRM"]
         types_w_anomaly = ['ModelMetricsAnomaly']
+        types_w_cox = ['ModelMetricsRegressionCoxPH']
 
         print()
         print(metric_type + ": " + self._algo)
@@ -163,12 +165,25 @@ class MetricsBase(h2o_meta()):
             self._metric_json["max_criteria_and_metric_scores"].show()
             if self.gains_lift():
                 print(self.gains_lift())
+        if metric_type in types_w_mult:
+            print("AUC: " + str(self.auc()))
+            print("AUCPR: " + str(self.aucpr()))
+            # AUC and PR AUC table cannot be computed due domain size
+            if self._metric_json["multinomial_auc_table"] is not None:
+                self._metric_json["multinomial_auc_table"].show()
+            else:
+                print("Multinomial auc values: Table is not computed because it is disabled (model parameter 'auc_type' is set to AUTO or NONE) or due to domain size (maximum is 50 domains).")
+            if self._metric_json["multinomial_aucpr_table"] is not None:
+                self._metric_json["multinomial_aucpr_table"].show()
+            else:
+                print("Multinomial auc_pr values: Table is not computed because it is disabled (model parameter 'auc_type' is set to AUTO or NONE) or due to domain size (maximum is 50 domains).")
         if metric_type in types_w_anomaly:
             print("Anomaly Score: " + str(self.mean_score()))
             print("Normalized Anomaly Score: " + str(self.mean_normalized_score()))
         if (metric_type in types_w_mult) or (metric_type in types_w_ord):
             self.confusion_matrix().show()
             self.hit_ratio_table().show()
+            
         if metric_type in types_w_clustering:
             print("Total Within Cluster Sum of Square Error: " + str(self.tot_withinss()))
             print("Total Sum of Square Error to Grand Mean: " + str(self.totss()))
@@ -178,6 +193,12 @@ class MetricsBase(h2o_meta()):
         if metric_type in types_w_dim:
             print("Sum of Squared Error (Numeric): " + str(self.num_err()))
             print("Misclassification Error (Categorical): " + str(self.cat_err()))
+            
+        if metric_type in types_w_cox:
+            print("Concordance score: " + str(self.concordance()))
+            print("Concordant count: " + str(self.concordant()))
+            print("Tied cout: " + str(self.tied_y()))
+        
         if self.custom_metric_name():
             print("{}: {}".format(self.custom_metric_name(), self.custom_metric_value()))
 
@@ -719,6 +740,56 @@ class H2OMultinomialModelMetrics(MetricsBase):
         return self._metric_json['hit_ratio_table']
 
 
+    def multinomial_auc_table(self):
+        """Retrieve the multinomial AUC values.
+
+        :examples:
+
+        >>> from h2o.estimators.gbm import H2OGradientBoostingEstimator
+        >>> cars = h2o.import_file("https://s3.amazonaws.com/h2o-public-test-data/smalldata/junit/cars_20mpg.csv")
+        >>> cars["cylinders"] = cars["cylinders"].asfactor()
+        >>> train, valid = cars.split_frame(ratios=[.8], seed=1234)
+        >>> response_col = "cylinders"
+        >>> distribution = "multinomial"
+        >>> predictors = ["displacement","power","weight","acceleration","year"]
+        >>> gbm = H2OGradientBoostingEstimator(nfolds=3,
+        ...                                    distribution = distribution)
+        >>> gbm.train(x=predictors,
+        ...           y = response,
+        ...           training_frame = train,
+        ...           validation_frame = valid)
+        >>> gbm.multinomial_auc_table()
+        """
+        if self._metric_json['multinomial_auc_table'] is not None:
+            return self._metric_json['multinomial_auc_table']
+        else:
+            return "Table is not computed because it is disabled (model parameter 'auc_type' is set to AUTO or NONE) or due to domain size (maximum is 50 domains)."
+
+    def multinomial_aucpr_table(self):
+        """Retrieve the multinomial PR AUC values.
+
+        :examples:
+
+        >>> from h2o.estimators.gbm import H2OGradientBoostingEstimator
+        >>> cars = h2o.import_file("https://s3.amazonaws.com/h2o-public-test-data/smalldata/junit/cars_20mpg.csv")
+        >>> cars["cylinders"] = cars["cylinders"].asfactor()
+        >>> train, valid = cars.split_frame(ratios=[.8], seed=1234)
+        >>> response_col = "cylinders"
+        >>> distribution = "multinomial"
+        >>> predictors = ["displacement","power","weight","acceleration","year"]
+        >>> gbm = H2OGradientBoostingEstimator(nfolds=3,
+        ...                                    distribution = distribution)
+        >>> gbm.train(x=predictors,
+        ...           y = response,
+        ...           training_frame = train,
+        ...           validation_frame = valid)
+        >>> gbm.multinomial_aucpr_table()
+        """
+        if self._metric_json['multinomial_aucpr_table'] is not None:
+            return self._metric_json['multinomial_aucpr_table']
+        else:
+            return "Table is not computed because it is disabled (model parameter 'auc_type' is set to AUTO or NONE) or due to domain size (maximum is 50 domains)."
+
 
 class H2OOrdinalModelMetrics(MetricsBase):
 
@@ -1255,7 +1326,6 @@ class H2OBinomialModelMetrics(MetricsBase):
                 )
         return errors
 
-
     def metric(self, metric, thresholds=None):
         """
         :param str metric: A metric among :const:`maximizing_metrics`.
@@ -1314,14 +1384,17 @@ class H2OBinomialModelMetrics(MetricsBase):
                 )
         return metrics
 
-
-    def plot(self, type="roc", server=False):
+    def plot(self, type="roc", server=False, save_to_file=None, plot=True):
         """
         Produce the desired metric plot.
 
-        :param type: the type of metric plot (currently, only ROC supported).
+        :param type: the type of metric plot (currently, only ROC curve ('roc') and Precision Recall curve ('pr') are supported).
         :param server: if True, generate plot inline using matplotlib's "Agg" backend.
-        :returns: None
+        :param save_to_file filename to save the plot to
+        :param plot True to plot curve, False to get a tuple of values at axis x and y of the plot 
+                (tprs and fprs for AUC, recall and precision for PR)
+        
+        :returns: None or values of x and y axis of the plot 
 
         :examples:
 
@@ -1336,27 +1409,58 @@ class H2OBinomialModelMetrics(MetricsBase):
         ...                y = response,
         ...                training_frame = train,
         ...                validation_frame = valid)
-        >>> cars_gbm.plot()
+        >>> cars_gbm.plot(type="roc")
+        >>> cars_gbm.plot(type="pr")
+        
         """
-        # TODO: add more types (i.e. cutoffs)
-        assert_is_type(type, "roc")
-        # check for matplotlib. exit if absent.
-        try:
-            import matplotlib
-            if server: matplotlib.use('Agg', warn=False)
-            import matplotlib.pyplot as plt
-        except ImportError:
-            print("matplotlib is required for this function!")
-            return
 
         if type == "roc":
+            return self._plot_roc(server, save_to_file, plot)
+        elif type == "pr":
+            return self._plot_pr(server, save_to_file, plot)
+    
+    def _plot_roc(self, server=False, save_to_file=None, plot=True):
+        if plot:
+            plt = get_matplotlib_pyplot(server)
+            if plt is None:
+                return
             plt.xlabel('False Positive Rate (FPR)')
             plt.ylabel('True Positive Rate (TPR)')
-            plt.title('ROC Curve')
+            plt.title('Receiver Operating Characteristic Curve')
             plt.text(0.5, 0.5, r'AUC={0:.4f}'.format(self._metric_json["AUC"]))
             plt.plot(self.fprs, self.tprs, 'b--')
             plt.axis([0, 1, 0, 1])
-            if not server: plt.show()
+            plt.grid(True)
+            plt.tight_layout()
+            if not server: 
+                plt.show()
+            if save_to_file is not None:  # only save when a figure is actually plotted
+                plt.savefig(save_to_file)
+        else:
+            return self.fprs, self.tprs
+
+    def _plot_pr(self, server=False, save_to_file=None, plot=True):
+        recalls = [x[0] for x in self.recall(thresholds='all')]
+        precisions = self.tprs
+        assert len(precisions) == len(recalls), "Precision and recall arrays must have the same length"
+        if plot:
+            plt = get_matplotlib_pyplot(server)
+            if plt is None:
+                return
+            plt.xlabel('Recall (TP/(TP+FP))')
+            plt.ylabel('Precision (TPR)')
+            plt.title('Precision Recall Curve')
+            plt.text(0.75, 0.95, r'auc_pr={0:.4f}'.format(self._metric_json["pr_auc"]))
+            plt.plot(recalls, precisions, 'b--')
+            plt.axis([0, 1, 0, 1])
+            plt.grid(True)
+            plt.tight_layout()
+            if not server: 
+                plt.show()
+            if save_to_file is not None:  # only save when a figure is actually plotted
+                plt.savefig(save_to_file)
+        else:
+            return recalls, precisions
 
 
     @property
@@ -1733,7 +1837,7 @@ class H2OAnomalyDetectionModelMetrics(MetricsBase):
         return None
 
 
-class H2OCoxPHModelMetrics(MetricsBase):
+class H2OModelMetricsRegressionCoxPH(MetricsBase):
     """
     :examples:
 
@@ -1746,8 +1850,28 @@ class H2OCoxPHModelMetrics(MetricsBase):
     >>> coxph
     """
 
+    def concordance(self):
+        """Concordance metrics (c-index). 
+        Proportion of concordant pairs divided by the total number of possible evaluation pairs.
+        1.0 for perfect match, 0.5 for random results."""
+        if MetricsBase._has(self._metric_json, "concordance"):
+            return self._metric_json["concordance"]
+        return None
+        
+    def concordant(self):
+        """Count of concordant pairs."""
+        if MetricsBase._has(self._metric_json, "concordant"):
+            return self._metric_json["concordant"]
+        return None  
+    
+    def tied_y(self):
+        """Count of tied pairs."""
+        if MetricsBase._has(self._metric_json, "tied_y"):
+            return self._metric_json["tied_y"]
+        return None
+
     def __init__(self, metric_json, on=None, algo=""):
-        super(H2OCoxPHModelMetrics, self).__init__(metric_json, on, algo)
+        super(H2OModelMetricsRegressionCoxPH, self).__init__(metric_json, on, algo)
 
 
 class H2OTargetEncoderMetrics(MetricsBase):
